@@ -17,7 +17,12 @@ from adb_shell.constants import DEFAULT_PUSH_MODE, DEFAULT_READ_TIMEOUT_S
 import aiofiles
 from ppadb.client import Client
 
-from ..constants import DEFAULT_ADB_TIMEOUT_S, DEFAULT_AUTH_TIMEOUT_S, DEFAULT_LOCK_TIMEOUT_S
+from ..constants import (
+    DEFAULT_ADB_TIMEOUT_S,
+    DEFAULT_AUTH_TIMEOUT_S,
+    DEFAULT_LOCK_TIMEOUT_S,
+    DEFAULT_TRANSPORT_TIMEOUT_S,
+)
 from ..exceptions import LockNotAcquiredException
 
 _LOGGER = logging.getLogger(__name__)
@@ -224,7 +229,12 @@ class ADBPythonAsync(object):
         """Close the ADB socket connection."""
         await self._adb.close()
 
-    async def connect(self, always_log_errors=True, auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S):
+    async def connect(
+        self,
+        always_log_errors=True,
+        auth_timeout_s=DEFAULT_AUTH_TIMEOUT_S,
+        transport_timeout_s=DEFAULT_TRANSPORT_TIMEOUT_S,
+    ):
         """Connect to an Android TV / Fire TV device.
 
         Parameters
@@ -233,6 +243,8 @@ class ADBPythonAsync(object):
             If True, errors will always be logged; otherwise, errors will only be logged on the first failed reconnect attempt
         auth_timeout_s : float
             Authentication timeout (in seconds)
+        transport_timeout_s : float
+            Transport timeout (in seconds)
 
         Returns
         -------
@@ -250,12 +262,14 @@ class ADBPythonAsync(object):
                             self._signer = await self.load_adbkey(self.adbkey)
 
                         await self._adb.connect(
-                            rsa_keys=[self._signer], transport_timeout_s=1.0, auth_timeout_s=auth_timeout_s
+                            rsa_keys=[self._signer],
+                            transport_timeout_s=transport_timeout_s,
+                            auth_timeout_s=auth_timeout_s,
                         )
 
                     # Connect without authentication
                     else:
-                        await self._adb.connect(transport_timeout_s=1.0, auth_timeout_s=auth_timeout_s)
+                        await self._adb.connect(transport_timeout_s=transport_timeout_s, auth_timeout_s=auth_timeout_s)
 
                     # ADB connection successfully established
                     _LOGGER.debug("ADB connection to %s:%d successfully established", self.host, self.port)
