@@ -66,7 +66,11 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
     """
 
-    def __init__(self, adb, host, port=5555, adbkey='', adb_server_ip='', adb_server_port=5037, state_detection_rules=None):
+    DEVICE_ENUM = constants.DeviceEnum.BASETV
+
+    def __init__(
+        self, adb, host, port=5555, adbkey="", adb_server_ip="", adb_server_port=5037, state_detection_rules=None
+    ):
         self._adb = adb
         self.host = host
         self.port = int(port)
@@ -77,14 +81,6 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         self.device_properties = {}
         self.installed_apps = []
 
-        # commands that can vary based on the device
-        self._cmd_get_properties_lazy_running_apps = ""
-        self._cmd_get_properties_lazy_no_running_apps = ""
-        self._cmd_get_properties_not_lazy_running_apps = ""
-        self._cmd_get_properties_not_lazy_no_running_apps = ""
-        self._cmd_current_app = ""
-        self._cmd_launch_app = ""
-
         # make sure the rules are valid
         if self._state_detection_rules:
             for app_id, rules in self._state_detection_rules.items():
@@ -95,12 +91,152 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         # the max volume level (determined when first getting the volume level)
         self.max_volume = None
 
-    def _fill_in_commands(self):
-        """Fill in commands that are specific to the device.
+        # Customizable commands
+        self._custom_commands = {}
 
-        This is implemented in the `BaseAndroidTV` and `BaseFireTV` classes.
+    # ======================================================================= #
+    #                                                                         #
+    #                      Device-specific ADB commands                       #
+    #                                                                         #
+    # ======================================================================= #
+    def customize_command(self, custom_command, value):
+        """Customize a command used to retrieve properties.
+
+        Parameters
+        ----------
+        custom_command : str
+            The name of the command that will be customized; it must be in `constants.CUSTOMIZABLE_COMMANDS`
+        value : str, None
+            The custom ADB command that will be used, or ``None`` if the custom command should be deleted
 
         """
+        if custom_command in constants.CUSTOMIZABLE_COMMANDS:
+            if value is not None:
+                self._custom_commands[custom_command] = value
+            elif custom_command in self._custom_commands:
+                del self._custom_commands[custom_command]
+
+    def _cmd_current_app(self):
+        """Get the command used to retrieve the current app for this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to determine the current app
+
+        """
+        if constants.CUSTOM_CURRENT_APP in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_CURRENT_APP]
+
+        # Is this a Google Chromecast Android TV?
+        if (
+            self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV
+            and "Google" in self.device_properties.get("manufacturer", "")
+            and "Chromecast" in self.device_properties.get("model", "")
+        ):
+            return constants.CMD_CURRENT_APP_GOOGLE_TV
+
+        return constants.CMD_CURRENT_APP
+
+    def _cmd_current_app_media_session_state(self):
+        """Get the command used to retrieve the current app and media session state for this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to determine the current app and media session state
+
+        """
+        if constants.CUSTOM_CURRENT_APP_MEDIA_SESSION_STATE in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_CURRENT_APP_MEDIA_SESSION_STATE]
+
+        # Is this a Google Chromecast Android TV?
+        if (
+            self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV
+            and "Google" in self.device_properties.get("manufacturer", "")
+            and "Chromecast" in self.device_properties.get("model", "")
+        ):
+            return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE_GOOGLE_TV
+
+        return constants.CMD_CURRENT_APP_MEDIA_SESSION_STATE
+
+    def _cmd_launch_app(self, app):
+        """Get the command to launch the specified app for this device.
+
+        Parameters
+        ----------
+        app : str
+            The app that will be launched
+
+        Returns
+        -------
+        str
+            The device-specific command to launch the app
+
+        """
+        if constants.CUSTOM_LAUNCH_APP in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_LAUNCH_APP].format(app)
+
+        # Is this a Google Chromecast Android TV?
+        if (
+            self.DEVICE_ENUM == constants.DeviceEnum.ANDROIDTV
+            and "Google" in self.device_properties.get("manufacturer", "")
+            and "Chromecast" in self.device_properties.get("model", "")
+        ):
+            return constants.CMD_LAUNCH_APP_GOOGLE_TV.format(app)
+
+        return constants.CMD_LAUNCH_APP.format(app)
+
+    def _cmd_running_apps(self):
+        """Get the command used to retrieve the running apps for this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to determine the running apps
+
+        """
+        if constants.CUSTOM_RUNNING_APPS in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_RUNNING_APPS]
+
+        if self.DEVICE_ENUM == constants.DeviceEnum.FIRETV:
+            return constants.CMD_RUNNING_APPS_FIRETV
+
+        return constants.CMD_RUNNING_APPS_ANDROIDTV
+
+    def _cmd_turn_off(self):
+        """Get the command used to turn off this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to turn off the device
+
+        """
+        if constants.CUSTOM_TURN_OFF in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_TURN_OFF]
+
+        if self.DEVICE_ENUM == constants.DeviceEnum.FIRETV:
+            return constants.CMD_TURN_OFF_FIRETV
+
+        return constants.CMD_TURN_OFF_ANDROIDTV
+
+    def _cmd_turn_on(self):
+        """Get the command used to turn on this device.
+
+        Returns
+        -------
+        str
+            The device-specific ADB shell command used to turn on the device
+
+        """
+        if constants.CUSTOM_TURN_ON in self._custom_commands:
+            return self._custom_commands[constants.CUSTOM_TURN_ON]
+
+        if self.DEVICE_ENUM == constants.DeviceEnum.FIRETV:
+            return constants.CMD_TURN_ON_FIRETV
+
+        return constants.CMD_TURN_ON_ANDROIDTV
 
     # ======================================================================= #
     #                                                                         #
@@ -134,7 +270,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             ``cmd`` with the 'adb shell ' prefix removed, if it was present
 
         """
-        return cmd[len("adb shell "):] if cmd.startswith("adb shell ") else cmd
+        return cmd[len("adb shell ") :] if cmd.startswith("adb shell ") else cmd
 
     # ======================================================================= #
     #                                                                         #
@@ -150,7 +286,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             The output of the ADB command that retrieves the device properties
 
         This method fills in the ``device_properties`` attribute, which is a dictionary with keys
-        ``'wifimac'``, ``'ethmac'``, ``'serialno'``, ``'manufacturer'``, ``'model'``, and ``'sw_version'``
+        ``'serialno'``, ``'manufacturer'``, ``'model'``, and ``'sw_version'``
 
         """
         _LOGGER.debug("%s:%d `get_device_properties` response: %s", self.host, self.port, properties)
@@ -160,43 +296,55 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             return
 
         lines = properties.strip().splitlines()
-        if len(lines) != 6:
+        if len(lines) != 4:
             self.device_properties = {}
             return
 
-        manufacturer, model, serialno, version, mac_wlan0_output, mac_eth0_output = lines
+        manufacturer, model, serialno, version = lines
 
         if not serialno.strip():
             _LOGGER.warning("Could not obtain serialno for %s:%d, got: '%s'", self.host, self.port, serialno)
             serialno = None
 
-        mac_wlan0_matches = re.findall(constants.MAC_REGEX_PATTERN, mac_wlan0_output)
-        if mac_wlan0_matches:
-            wifimac = mac_wlan0_matches[0]
-        else:
-            wifimac = None
+        self.device_properties = {
+            "manufacturer": manufacturer,
+            "model": model,
+            "serialno": serialno,
+            "sw_version": version,
+        }
 
-        mac_eth0_matches = re.findall(constants.MAC_REGEX_PATTERN, mac_eth0_output)
-        if mac_eth0_matches:
-            ethmac = mac_eth0_matches[0]
-        else:
-            ethmac = None
+    @staticmethod
+    def _parse_mac_address(mac_response):
+        """Parse a MAC address from the ADB shell response.
 
-        self.device_properties = {'manufacturer': manufacturer,
-                                  'model': model,
-                                  'serialno': serialno,
-                                  'sw_version': version,
-                                  'wifimac': wifimac,
-                                  'ethmac': ethmac}
+        Parameters
+        ----------
+        mac_response : str, None
+            The response from the MAC address ADB shell command
 
-        self._fill_in_commands()
+        Returns
+        -------
+        str, None
+            The parsed MAC address, or ``None`` if it could not be determined
+
+        """
+        if not mac_response:
+            return None
+
+        mac_matches = re.findall(constants.MAC_REGEX_PATTERN, mac_response)
+        if mac_matches:
+            return mac_matches[0]
+
+        return None
 
     # ======================================================================= #
     #                                                                         #
     #                         Custom state detection                          #
     #                                                                         #
     # ======================================================================= #
-    def _custom_state_detection(self, current_app=None, media_session_state=None, wake_lock_size=None, audio_state=None):
+    def _custom_state_detection(
+        self, current_app=None, media_session_state=None, wake_lock_size=None, audio_state=None
+    ):
         """Use the rules in ``self._state_detection_rules`` to determine the state.
 
         Parameters
@@ -227,7 +375,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
                 return rule
 
             # Use the `media_session_state` property
-            if rule == 'media_session_state':
+            if rule == "media_session_state":
                 if media_session_state == 2:
                     return constants.STATE_PAUSED
                 if media_session_state == 3:
@@ -236,13 +384,15 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
                     return constants.STATE_IDLE
 
             # Use the `audio_state` property
-            if rule == 'audio_state' and audio_state in constants.VALID_STATES:
+            if rule == "audio_state" and audio_state in constants.VALID_STATES:
                 return audio_state
 
             # Check conditions and if they are true, return the specified state
             if isinstance(rule, dict):
                 for state, conditions in rule.items():
-                    if state in constants.VALID_STATES and self._conditions_are_true(conditions, media_session_state, wake_lock_size, audio_state):
+                    if state in constants.VALID_STATES and self._conditions_are_true(
+                        conditions, media_session_state, wake_lock_size, audio_state
+                    ):
                         return state
 
         return None
@@ -269,15 +419,15 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
         """
         for key, val in conditions.items():
-            if key == 'media_session_state':
+            if key == "media_session_state":
                 if media_session_state is None or media_session_state != val:
                     return False
 
-            elif key == 'wake_lock_size':
+            elif key == "wake_lock_size":
                 if wake_lock_size is None or wake_lock_size != val:
                     return False
 
-            elif key == 'audio_state':
+            elif key == "audio_state":
                 if audio_state is None or audio_state != val:
                     return False
 
@@ -333,20 +483,20 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         """
         if not audio_state_response:
             return None
-        if audio_state_response == '1':
+        if audio_state_response == "1":
             return constants.STATE_PAUSED
-        if audio_state_response == '2':
+        if audio_state_response == "2":
             return constants.STATE_PLAYING
         return constants.STATE_IDLE
 
     @staticmethod
     def _current_app(current_app_response):
-        """Get the current app from the output of the command :py:const:`androidtv.constants.CMD_CURRENT_APP`.
+        """Get the current app from the output of the command `androidtv.basetv.basetv.BaseTV._cmd_current_app`.
 
         Parameters
         ----------
         current_app_response : str, None
-            The output from the ADB command :py:const:`androidtv.constants.CMD_CURRENT_APP`
+            The output from the ADB command `androidtv.basetv.basetv.BaseTV._cmd_current_app`
 
         Returns
         -------
@@ -354,18 +504,18 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             The current app, or ``None`` if it could not be determined
 
         """
-        if not current_app_response or '=' in current_app_response or '{' in current_app_response:
+        if not current_app_response or "=" in current_app_response or "{" in current_app_response:
             return None
 
         return current_app_response
 
-    def _current_app_media_session_state(self, media_session_state_response):
-        """Get the current app and the media session state properties from the output of :py:const:`androidtv.constants.CMD_MEDIA_SESSION_STATE_FULL`.
+    def _current_app_media_session_state(self, current_app_media_session_state_response):
+        """Get the current app and the media session state properties from the output of `androidtv.basetv.basetv.BaseTV._cmd_current_app_media_session_state`.
 
         Parameters
         ----------
-        media_session_state_response : str, None
-            The output of :py:const:`androidtv.constants.CMD_MEDIA_SESSION_STATE_FULL`
+        current_app_media_session_state_response : str, None
+            The output of `androidtv.basetv.basetv.BaseTV._cmd_current_app_media_session_state`
 
         Returns
         -------
@@ -375,19 +525,19 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             The state from the output of the ADB shell command, or ``None`` if it could not be determined
 
         """
-        if not media_session_state_response:
+        if not current_app_media_session_state_response:
             return None, None
 
-        lines = media_session_state_response.splitlines()
+        lines = current_app_media_session_state_response.splitlines()
 
         current_app = self._current_app(lines[0].strip())
 
         if len(lines) > 1:
-            media_session_state = self._media_session_state(lines[1], current_app)
-        else:
-            media_session_state = None
+            matches = constants.REGEX_MEDIA_SESSION_STATE.search(current_app_media_session_state_response)
+            if matches:
+                return current_app, int(matches.group("state"))
 
-        return current_app, media_session_state
+        return current_app, None
 
     @staticmethod
     def _get_hdmi_input(hdmi_response):
@@ -422,7 +572,9 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
         """
         if installed_apps_response is not None:
-            return [line.strip().rsplit("package:", 1)[-1] for line in installed_apps_response.splitlines() if line.strip()]
+            return [
+                line.strip().rsplit("package:", 1)[-1] for line in installed_apps_response.splitlines() if line.strip()
+            ]
 
         return None
 
@@ -446,33 +598,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
         matches = re.findall(constants.MUTED_REGEX_PATTERN, stream_music, re.DOTALL | re.MULTILINE)
         if matches:
-            return matches[0] == 'true'
-
-        return None
-
-    @staticmethod
-    def _media_session_state(media_session_state_response, current_app):
-        """Get the state from the output of :py:const:`androidtv.constants.CMD_MEDIA_SESSION_STATE`.
-
-        Parameters
-        ----------
-        media_session_state_response : str, None
-            The output of :py:const:`androidtv.constants.CMD_MEDIA_SESSION_STATE`
-        current_app : str, None
-            The current app, or ``None`` if it could not be determined
-
-        Returns
-        -------
-        int, None
-            The state from the output of the ADB shell command, or ``None`` if it could not be determined
-
-        """
-        if not media_session_state_response or not current_app:
-            return None
-
-        matches = constants.REGEX_MEDIA_SESSION_STATE.search(media_session_state_response)
-        if matches:
-            return int(matches.group('state'))
+            return matches[0] == "true"
 
         return None
 
@@ -516,12 +642,41 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
 
         """
         if running_apps_response:
-            if isinstance(running_apps_response, list):
-                return [line.strip().rsplit(' ', 1)[-1] for line in running_apps_response if line.strip()]
-            return [line.strip().rsplit(' ', 1)[-1] for line in running_apps_response.splitlines() if line.strip()]
+            return [line.strip().rsplit(" ", 1)[-1] for line in running_apps_response.splitlines() if line.strip()]
 
         return None
 
+    @staticmethod
+    def _screen_on_awake_wake_lock_size(output):
+        """Check if the screen is on and the device is awake, and get the wake lock size.
+
+        Parameters
+        ----------
+        output : str, None
+            The output from :py:const:`androidtv.constants.CMD_SCREEN_ON_AWAKE_WAKE_LOCK_SIZE`
+
+        Returns
+        -------
+        bool, None
+            Whether or not the device is on, or ``None`` if it could not be determined
+        bool, None
+            Whether or not the device is awake (screensaver is not running), or ``None`` if it could not be determined
+        int, None
+            The size of the current wake lock, or ``None`` if it could not be determined
+
+        """
+        if output is None:
+            return None, None, None
+
+        if output == "":
+            return False, False, None
+
+        screen_on = output[0] == "1"
+        awake = None if len(output) < 2 else output[1] == "1"
+        wake_lock_size = None if len(output) < 3 else BaseTV._wake_lock_size(output[2:])
+
+        return screen_on, awake, wake_lock_size
+
     def _volume(self, stream_music, audio_output_device):
         """Get the absolute volume level from the ``STREAM_MUSIC`` block from ``adb shell dumpsys audio``.
 
@@ -545,13 +700,13 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
             max_volume_matches = re.findall(constants.MAX_VOLUME_REGEX_PATTERN, stream_music, re.DOTALL | re.MULTILINE)
             if max_volume_matches:
                 self.max_volume = float(max_volume_matches[0])
-            else:
-                self.max_volume = 15.
 
         if not audio_output_device:
             return None
 
-        volume_matches = re.findall(audio_output_device + constants.VOLUME_REGEX_PATTERN, stream_music, re.DOTALL | re.MULTILINE)
+        volume_matches = re.findall(
+            audio_output_device + constants.VOLUME_REGEX_PATTERN, stream_music, re.DOTALL | re.MULTILINE
+        )
         if volume_matches:
             return int(volume_matches[0])
 
@@ -594,7 +749,7 @@ class BaseTV(object):  # pylint: disable=too-few-public-methods
         if wake_lock_size_response:
             wake_lock_size_matches = constants.REGEX_WAKE_LOCK_SIZE.search(wake_lock_size_response)
             if wake_lock_size_matches:
-                return int(wake_lock_size_matches.group('size'))
+                return int(wake_lock_size_matches.group("size"))
 
         return None
 
@@ -664,7 +819,11 @@ def state_detection_rules_validator(rules, exc=KeyError):
         # If a rule is a string, check that it is valid
         if isinstance(rule, str):
             if rule not in constants.VALID_STATE_PROPERTIES + constants.VALID_STATES:
-                raise exc("Invalid rule '{0}' is not in {1}".format(rule, constants.VALID_STATE_PROPERTIES + constants.VALID_STATES))
+                raise exc(
+                    "Invalid rule '{0}' is not in {1}".format(
+                        rule, constants.VALID_STATE_PROPERTIES + constants.VALID_STATES
+                    )
+                )
 
         # If a rule is a dictionary, check that it is valid
         else:
@@ -675,7 +834,11 @@ def state_detection_rules_validator(rules, exc=KeyError):
 
                 # The values of the dictionary must be dictionaries
                 if not isinstance(conditions, dict):
-                    raise exc("Expected a map for entry '{0}' in 'state_detection_rules', got {1}".format(state, type(conditions).__name__))
+                    raise exc(
+                        "Expected a map for entry '{0}' in 'state_detection_rules', got {1}".format(
+                            state, type(conditions).__name__
+                        )
+                    )
 
                 for prop, value in conditions.items():
                     # The keys of the dictionary must be valid properties that can be checked
@@ -684,6 +847,10 @@ def state_detection_rules_validator(rules, exc=KeyError):
 
                     # Make sure the value is of the right type
                     if not isinstance(value, constants.VALID_PROPERTIES_TYPES[prop]):
-                        raise exc("Conditional value for property '{0}' must be of type {1}, not {2}".format(prop, constants.VALID_PROPERTIES_TYPES[prop].__name__, type(value).__name__))
+                        raise exc(
+                            "Conditional value for property '{0}' must be of type {1}, not {2}".format(
+                                prop, constants.VALID_PROPERTIES_TYPES[prop].__name__, type(value).__name__
+                            )
+                        )
 
     return rules
